@@ -7,6 +7,7 @@ import random
 import json
 import requests
 from .Config import colors
+from .Storage import commandsRegistered, getCommand, executeCommand, registerCommand
 
 ###################
 ### Goobler 2022 ##
@@ -29,11 +30,16 @@ from .Config import colors
 # PURE FUNCS:
 
 def start(tkn):
-  resp = requests.get("https://goobl2.ericplayzyt.repl.co/api/get_name_using_auth", {"auth": f"{tkn}"})
-  print(f"Starting {resp['name']}...")
+  resp = requests.get("https://goobl2.ericplayzyt.repl.co/api/get_name_using_auth", {"auth": f"{tkn}"}).text
+  print(f"Starting bot({resp})...")
   resp2 = requests.post("https://goobl2.ericplayzyt.repl.co/api/login/bot_account", {"auth": f"{tkn}"})
-  print(resp['name'] + "has logged in.")
+  print(colors.BOLD + resp + " has logged in." + colors.ENDC)
+  registerCommand("help", help)
 
 def Application(client_id=None, token=None):
   if token == None:
-    print(colors._FAIL + colors._BOLD + colors._UNDERLINE + "[GooblerAPI] You cannot execute 'MakeApplication' without the positional arguments, token. Remember, the token is the admin password to your application.")
\ No newline at end of file
+    print(colors._FAIL + colors._BOLD + colors._UNDERLINE + "[GooblerAPI] You cannot execute 'MakeApplication' without the positional arguments, token. Remember, the token is the admin password to your application.")
+
+
+while True:
+  getCommand("help")
\ No newline at end of file
